(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     10341,        412]
NotebookOptionsPosition[      8324,        333]
NotebookOutlinePosition[      8660,        348]
CellTagsIndexPosition[      8617,        345]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Eigensystems of canonical hyperbolic systems\
\>", "Section",
 CellChangeTimes->{{3.535985097125519*^9, 3.535985109396997*^9}}],

Cell[CellGroupData[{

Cell["Linear systems", "Subsection",
 CellChangeTimes->{{3.535985117789422*^9, 3.535985121565105*^9}}],

Cell[CellGroupData[{

Cell["Elasticity equations", "Subsubsection",
 CellChangeTimes->{{3.5359851265497293`*^9, 3.535985130380989*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A", "=", 
  RowBox[{"(", GridBox[{
     {"0", 
      RowBox[{"-", "Ex"}]},
     {
      RowBox[{
       RowBox[{"-", "1"}], "/", "\[Rho]"}], "0"}
    }], ")"}]}]], "Input",
 CellChangeTimes->{{3.535985134853775*^9, 3.5359851942997837`*^9}, 
   3.5359853211409283`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "Ex"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "\[Rho]"]}], ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5359851636622267`*^9, 3.535985322389497*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Lambda]", "=", 
  RowBox[{"Eigenvalues", "[", "A", "]"}]}]], "Input",
 CellChangeTimes->{{3.535985333446803*^9, 3.535985339057472*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     SqrtBox["Ex"], 
     SqrtBox["\[Rho]"]]}], ",", 
   FractionBox[
    SqrtBox["Ex"], 
    SqrtBox["\[Rho]"]]}], "}"}]], "Output",
 CellChangeTimes->{3.535985339686607*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"r", "=", 
  RowBox[{"Eigenvectors", "[", "A", "]"}]}]], "Input",
 CellChangeTimes->{{3.535985343897201*^9, 3.535985348065838*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SqrtBox["Ex"], " ", 
      SqrtBox["\[Rho]"]}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SqrtBox["Ex"]}], " ", 
      SqrtBox["\[Rho]"]}], ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5359853499979687`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"A", " ", ".", " ", 
   RowBox[{"r", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], " ", "-", " ", 
  RowBox[{
   RowBox[{"\[Lambda]", "[", 
    RowBox[{"[", "1", "]"}], "]"}], " ", 
   RowBox[{"r", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.535985410355049*^9, 3.5359854350557528`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.535985415741968*^9, 3.535985436427445*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"A", " ", ".", " ", 
   RowBox[{"r", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], " ", "-", " ", 
  RowBox[{
   RowBox[{"\[Lambda]", "[", 
    RowBox[{"[", "2", "]"}], "]"}], " ", 
   RowBox[{"r", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.535985410355049*^9, 3.535985443564755*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.535985444448601*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Inverse", "[", "r", "]"}]], "Input",
 CellChangeTimes->{{3.5359855676991453`*^9, 3.5359855699845943`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", " ", 
       SqrtBox["Ex"], " ", 
       SqrtBox["\[Rho]"]}]], ",", 
     RowBox[{"-", 
      FractionBox["1", 
       RowBox[{"2", " ", 
        SqrtBox["Ex"], " ", 
        SqrtBox["\[Rho]"]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", 
     FractionBox["1", "2"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.535985570667726*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Acoustics equations", "Subsubsection",
 CellChangeTimes->{{3.535987106214128*^9, 3.535987108829629*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A", "=", 
  RowBox[{"(", GridBox[{
     {"0", 
      RowBox[{
       SubscriptBox["\[Rho]", "0"], 
       SuperscriptBox["c", "2"]}]},
     {
      RowBox[{"1", "/", 
       SubscriptBox["\[Rho]", "0"]}], "0"}
    }], ")"}]}]], "Input",
 CellChangeTimes->{{3.535987112427062*^9, 3.5359871930924587`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      SubscriptBox["\[Rho]", "0"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", 
      SubscriptBox["\[Rho]", "0"]], ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.535987194026248*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Lambda]", "=", 
  RowBox[{"Eigenvalues", "[", "A", "]"}]}]], "Input",
 CellChangeTimes->{{3.535985333446803*^9, 3.535985339057472*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "c"}], ",", "c"}], "}"}]], "Output",
 CellChangeTimes->{3.535985339686607*^9, 3.535987208662026*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"r", "=", 
  RowBox[{"Eigenvectors", "[", "A", "]"}]}]], "Input",
 CellChangeTimes->{{3.535985343897201*^9, 3.535985348065838*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "c"}], " ", 
      SubscriptBox["\[Rho]", "0"]}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"c", " ", 
      SubscriptBox["\[Rho]", "0"]}], ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5359853499979687`*^9, 3.5359872119288*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"A", " ", ".", " ", 
   RowBox[{"r", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], " ", "-", " ", 
  RowBox[{
   RowBox[{"\[Lambda]", "[", 
    RowBox[{"[", "1", "]"}], "]"}], " ", 
   RowBox[{"r", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.535985410355049*^9, 3.5359854350557528`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.535985415741968*^9, 3.535985436427445*^9}, 
   3.535987214604254*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"A", " ", ".", " ", 
   RowBox[{"r", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], " ", "-", " ", 
  RowBox[{
   RowBox[{"\[Lambda]", "[", 
    RowBox[{"[", "2", "]"}], "]"}], " ", 
   RowBox[{"r", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.535985410355049*^9, 3.535985443564755*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.535985444448601*^9, 3.535987216738481*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Inverse", "[", "r", "]"}]], "Input",
 CellChangeTimes->{{3.535987262566022*^9, 3.5359872654974527`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", 
       RowBox[{"2", " ", "c", " ", 
        SubscriptBox["\[Rho]", "0"]}]]}], ",", 
     FractionBox["1", 
      RowBox[{"2", " ", "c", " ", 
       SubscriptBox["\[Rho]", "0"]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", 
     FractionBox["1", "2"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.535987265840589*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Nonlinear equations", "Subsection",
 CellChangeTimes->{{3.535987295606188*^9, 3.5359872980860577`*^9}}],

Cell[CellGroupData[{

Cell["Shallow water equations", "Subsubsection",
 CellChangeTimes->{{3.535987300414444*^9, 3.535987303589699*^9}}],

Cell[BoxData[
 RowBox[{"f", "=", "{"}]], "Input",
 CellChangeTimes->{
  3.535987552666999*^9, {3.535987591450767*^9, 3.535987598313665*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{740, 858},
WindowMargins->{{Automatic, 271}, {Automatic, 1}},
FrontEndVersion->"8.0 for Linux x86 (64-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 137, 3, 72, "Section"],
Cell[CellGroupData[{
Cell[741, 29, 102, 1, 37, "Subsection"],
Cell[CellGroupData[{
Cell[868, 34, 113, 1, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[1006, 39, 292, 10, 44, "Input"],
Cell[1301, 51, 310, 10, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1648, 66, 161, 3, 30, "Input"],
Cell[1812, 71, 249, 10, 58, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2098, 86, 154, 3, 30, "Input"],
Cell[2255, 91, 366, 14, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2658, 110, 353, 10, 30, "Input"],
Cell[3014, 122, 139, 3, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3190, 130, 351, 10, 30, "Input"],
Cell[3544, 142, 115, 3, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3696, 150, 130, 2, 30, "Input"],
Cell[3829, 154, 488, 18, 52, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4366, 178, 110, 1, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[4501, 183, 328, 11, 46, "Input"],
Cell[4832, 196, 353, 12, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5222, 213, 161, 3, 30, "Input"],
Cell[5386, 218, 156, 4, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5579, 227, 154, 3, 30, "Input"],
Cell[5736, 232, 371, 12, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6144, 249, 353, 10, 30, "Input"],
Cell[6500, 261, 165, 4, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6702, 270, 351, 10, 30, "Input"],
Cell[7056, 282, 137, 3, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7230, 290, 128, 2, 30, "Input"],
Cell[7361, 294, 471, 16, 49, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7893, 317, 109, 1, 37, "Subsection"],
Cell[CellGroupData[{
Cell[8027, 322, 114, 1, 28, "Subsubsection"],
Cell[8144, 325, 140, 3, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

