(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[      8053,        313]
NotebookOptionsPosition[      6900,        266]
NotebookOutlinePosition[      7237,        281]
CellTagsIndexPosition[      7194,        278]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Shallow water eigensystem", "Subsubtitle",
 CellChangeTimes->{{3.5382399146257887`*^9, 3.538239918537236*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "=", 
  RowBox[{"{", 
   RowBox[{"l", ",", 
    RowBox[{
     RowBox[{
      SuperscriptBox["l", "2"], "/", "h"}], "+", 
     RowBox[{
      RowBox[{"g", "/", "2"}], " ", 
      SuperscriptBox["h", "2"]}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.538239716242298*^9, 3.5382397421763783`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"l", ",", 
   RowBox[{
    FractionBox[
     RowBox[{"g", " ", 
      SuperscriptBox["h", "2"]}], "2"], "+", 
    FractionBox[
     SuperscriptBox["l", "2"], "h"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.53823974375609*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Jac", "=", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{"f", ",", "h"}], "]"}], ",", 
     RowBox[{"D", "[", 
      RowBox[{"f", ",", "l"}], "]"}]}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.538239747045664*^9, 3.53823981798424*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"g", " ", "h"}], "-", 
      FractionBox[
       SuperscriptBox["l", "2"], 
       SuperscriptBox["h", "2"]]}], ",", 
     FractionBox[
      RowBox[{"2", " ", "l"}], "h"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.5382397919981823`*^9, 3.5382398187912827`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixForm", "[", "Jac", "]"}]], "Input",
 CellChangeTimes->{{3.538239805022319*^9, 3.538239809011922*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "1"},
     {
      RowBox[{
       RowBox[{"g", " ", "h"}], "-", 
       FractionBox[
        SuperscriptBox["l", "2"], 
        SuperscriptBox["h", "2"]]}], 
      FractionBox[
       RowBox[{"2", " ", "l"}], "h"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.538239809503827*^9, 3.538239821407946*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"JacP", " ", "=", " ", 
  RowBox[{"Jac", " ", "/.", " ", 
   RowBox[{"l", "\[Rule]", "  ", 
    RowBox[{"h", " ", "u"}]}]}]}]], "Input",
 CellChangeTimes->{{3.538239827042644*^9, 3.538239841670329*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"g", " ", "h"}], "-", 
      SuperscriptBox["u", "2"]}], ",", 
     RowBox[{"2", " ", "u"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.538239844309559*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixForm", "[", "JacP", "]"}]], "Input",
 CellChangeTimes->{{3.5382398477572927`*^9, 3.538239852164143*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "1"},
     {
      RowBox[{
       RowBox[{"g", " ", "h"}], "-", 
       SuperscriptBox["u", "2"]}], 
      RowBox[{"2", " ", "u"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.538239852593362*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Eigensystem", "[", "JacP", "]"}]], "Input",
 CellChangeTimes->{{3.5382398565848293`*^9, 3.538239863348159*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SqrtBox["g"]}], " ", 
       SqrtBox["h"]}], "+", "u"}], ",", 
     RowBox[{
      RowBox[{
       SqrtBox["g"], " ", 
       SqrtBox["h"]}], "+", "u"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", 
         RowBox[{
          RowBox[{
           SqrtBox["g"], " ", 
           SqrtBox["h"]}], "-", "u"}]]}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SqrtBox["g"]}], " ", 
           SqrtBox["h"]}], "-", "u"}]]}], ",", "1"}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.5382398639257183`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalLambda]", "=", 
  RowBox[{"Eigenvalues", "[", "JacP", "]"}]}]], "Input",
 CellChangeTimes->{{3.5382398756480207`*^9, 3.5382398856927013`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SqrtBox["g"]}], " ", 
     SqrtBox["h"]}], "+", "u"}], ",", 
   RowBox[{
    RowBox[{
     SqrtBox["g"], " ", 
     SqrtBox["h"]}], "+", "u"}]}], "}"}]], "Output",
 CellChangeTimes->{3.53823988713801*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"R", "=", 
  RowBox[{"Eigenvectors", "[", "JacP", "]"}]}]], "Input",
 CellChangeTimes->{{3.5382398888907547`*^9, 3.538239894525261*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", 
       RowBox[{
        RowBox[{
         SqrtBox["g"], " ", 
         SqrtBox["h"]}], "-", "u"}]]}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SqrtBox["g"]}], " ", 
         SqrtBox["h"]}], "-", "u"}]]}], ",", "1"}], "}"}]}], "}"}]], "Output",\

 CellChangeTimes->{3.538239895022708*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{735, 858},
WindowMargins->{{145, Automatic}, {Automatic, 29}},
FrontEndVersion->"8.0 for Linux x86 (64-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 116, 1, 31, "Subsubtitle"],
Cell[CellGroupData[{
Cell[720, 27, 324, 10, 34, "Input"],
Cell[1047, 39, 265, 9, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1349, 53, 317, 9, 30, "Input"],
Cell[1669, 64, 428, 14, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2134, 83, 131, 2, 30, "Input"],
Cell[2268, 87, 845, 25, 71, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3150, 117, 225, 5, 30, "Input"],
Cell[3378, 124, 320, 11, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3735, 140, 134, 2, 30, "Input"],
Cell[3872, 144, 738, 22, 59, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4647, 171, 135, 2, 30, "Input"],
Cell[4785, 175, 856, 34, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5678, 214, 175, 3, 30, "Input"],
Cell[5856, 219, 294, 12, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6187, 236, 159, 3, 30, "Input"],
Cell[6349, 241, 523, 21, 53, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

